@@ -131,6 +131,17 @@ sub _build_uri {
     $self->request_builder->_build_uri($self);
 }
 
+has builder_options => (
+    is      => 'rw',
+    isa     => 'HashRef',
+    default => sub {
+        +{
+            disable_raw_body => 0,
+            upload_tmp       => undef,
+        },
+    },
+);
+
 has raw_body => (
     is      => 'rw',
     isa     => 'Str',
@@ -404,6 +415,48 @@ L<HTTP::Engine::RequestBuilder::CGI> or L<HTTP::Engine::RequestBuilder::NoEnv>.
 
 =over 4
 
+=item builder_options
+
+configuration for control of HTTP::Engine::RequestBuilder.
+
+=over 4
+
+=item disable_raw_body
+
+$req->raw_body is not saved.
+
+When receiving upload of a big file, it uses in order to prevent raw_body becoming large.
+
+raw_body is enabled by the default. because of back compatibility.
+
+  $req->upload('file1');
+  is $req->raw_body, '...some contents...';
+
+  $req->builder_options->{disable_raw_body} = 1;
+  $req->upload('file2');
+  is $req->raw_body, '';
+
+  $req->builder_options->{disable_raw_body} = 0;
+  $req->upload('file1');
+  is $req->raw_body, '...some contents...';
+
+=item upload_tmp
+
+change temporarily directory to store upload file.
+It changes of default temporarily directory by L<HTTP::Body>.
+
+generally use L<File::Temp>.
+
+  $req->builder_options->{upload_tmp} = File::Temp->newdir;
+
+for lazy make directory
+
+  $req->builder_options->{upload_tmp} = sub { File::Temp->newdir };
+
+In these examples, if request processing finishes, upload files will be deleted.
+
+=back
+
 =item address
 
 Returns the IP address of the client.
